(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     64822,       1551]
NotebookOptionsPosition[     60185,       1481]
NotebookOutlinePosition[     60683,       1499]
CellTagsIndexPosition[     60640,       1496]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 21 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}, {3.891080224224403*^9, 
   3.891080224709962*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9aff808c-ded9-4bf0-8637-19e7bf92455a"],

Cell["Chapter 9, Section 9.3.2, Figure 9.5", "Section",
 CellChangeTimes->{{3.878562412934669*^9, 3.878562413354199*^9}, {
  3.8846087172978783`*^9, 3.884608735388258*^9}, {3.884692304467482*^9, 
  3.8846923048123302`*^9}, {3.884936708324288*^9, 3.8849367128241863`*^9}, {
  3.885014699065946*^9, 
  3.885014699641323*^9}},ExpressionUUID->"98580719-04ac-49a4-b957-\
796e13d2fd0c"],

Cell[TextData[{
 "First we define a function ",
 StyleBox["CRTBP", "Input"],
 " which solves the circular restricted three-body problem for a given mass \
ratio and initial values of the position and velocity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884608962593175*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2196beda-83cc-4949-84e5-6855091b3920"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBP", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "xd0_", ",", "yd0_"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"ctmin_", ",", " ", "ctmax_"}], "}"}]}], "]"}], ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"eqns", " ", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r1", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{"r2", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{
           RowBox[{"xd", "'"}], "[", "t", "]"}], " ", "==", " ", 
          RowBox[{
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"y", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
           RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
           RowBox[{"mu1", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}]}], " ", "-", " ", 
           RowBox[{"mu2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", 
           RowBox[{
            RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
          RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"mu1", "/", 
              RowBox[{
               RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}], " ", "+", " ", 
             RowBox[{"mu2", "/", 
              RowBox[{
               RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}], ")"}], "*", 
           RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"x", "[", "ctmin", "]"}], "  ", "==", " ", "x0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"y", "[", "ctmin", "]"}], "  ", "==", " ", "y0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "ctmin", "]"}], " ", "==", " ", "xd0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "ctmin", "]"}], " ", "==", " ", "yd0"}]}], 
       "}"}]}], ";", 
     RowBox[{"NDSolve", "[", 
      RowBox[{"eqns", ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "xd", ",", "yd"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "ctmin", ",", "ctmax"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.884598673329917*^9, 3.884598776657687*^9}, 
   3.88503804742982*^9, {3.885038592349805*^9, 3.885038603185713*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a0cc8023-92c0-48cc-8003-9af569b81a86"],

Cell[TextData[{
 "Next we define the Jacobi integral ",
 StyleBox["Jacobi", "Input"],
 " for use as a check on the accuracy of our solution."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e62b02b3-a858-4e86-bbbf-40af19ca2286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Jacobi", "[", 
   RowBox[{"mu_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "xd_", ",", "yd_"}], "}"}]}], "]"}], ":=", 
  " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}], ",", " ", "r1", ",", " ", "r2"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r1", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "+", "mu2"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "-", "mu1"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mu1", "/", "r1"}], "+", 
         RowBox[{"mu2", "/", "r2"}]}], ")"}]}], "-", 
      RowBox[{"xd", "^", "2"}], "-", 
      RowBox[{"yd", "^", "2"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.88459882221215*^9, 3.8845988400166473`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"cc76bdeb-e5fc-4e00-a682-cd7f21c16a0c"],

Cell[TextData[{
 "The function ",
 StyleBox["xy2ae", "Input"],
 " converts position and velocity to orbital elements.  Note that it assumes \
that the position and velocity are given in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.884609189347991*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b21a35eb-c629-442c-bfb9-7016cce5ed6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xy2ae", "[", 
   RowBox[{"mu_", ",", " ", "tposvel_List"}], "]"}], " ", ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "x", ",", " ", 
      "y", ",", " ", "xd", ",", " ", "yd", ",", " ", "ct", ",", "st", ",", 
      "rx", ",", "ry", ",", "r2", ",", "r", ",", "vx", ",", "vy", ",", "v2", 
      ",", "v", ",", "a", ",", "h", ",", "h2", ",", "rdot", ",", "e", ",", 
      "xor", ",", "yor", ",", "cpf", ",", "sf", ",", "cf", ",", "f", ",", 
      "cp", ",", "ce", ",", "se", ",", "cpdeg", ",", "ea", ",", "ma", ",", 
      "lam"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "x", ",", " ", "y", ",", " ", "xd", ",", " ", "yd"}], 
       "}"}], " ", "=", " ", "tposvel"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{
       RowBox[{"ct", "*", "x"}], "-", 
       RowBox[{"st", "*", "y"}]}]}], ";", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{
       RowBox[{"st", "*", "x"}], "+", 
       RowBox[{"ct", "*", "y"}]}]}], ";", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{"x", "*", "x"}], "+", 
       RowBox[{"y", "*", "y"}]}]}], ";", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "r2", "]"}]}], ";", 
     RowBox[{"vx", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "ct"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"vy", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"v2", " ", "=", " ", 
      RowBox[{
       RowBox[{"vx", "*", "vx"}], " ", "+", " ", 
       RowBox[{"vy", "*", "vy"}]}]}], ";", 
     RowBox[{"v", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "v2", "]"}]}], ";", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "/", "r"}], " ", "-", " ", 
         RowBox[{"v2", "/", "mu1"}]}], ")"}]}]}], ";", 
     RowBox[{"h", " ", "=", " ", 
      RowBox[{
       RowBox[{"rx", "*", "vy"}], " ", "-", " ", 
       RowBox[{"ry", "*", "vx"}]}]}], ";", 
     RowBox[{"h2", " ", "=", " ", 
      RowBox[{"h", "*", "h"}]}], ";", 
     RowBox[{"rdot", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"rx", "*", "vx"}], "+", 
         RowBox[{"ry", "*", "vy"}]}], ")"}], "/", "r"}]}], ";", 
     RowBox[{"e", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"h2", "/", "mu1"}], "/", "a"}]}], "]"}]}], ";", 
     RowBox[{"cpf", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"rx", ",", " ", "ry"}], "]"}]}], ";", 
     RowBox[{"cf", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"e", "*", "e"}]}], ")"}], "/", "r"}]}], "-", "1"}], 
        ")"}], "/", "e"}]}], ";", 
     RowBox[{"sf", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "e"}]}], ")"}], "*", 
       RowBox[{
        RowBox[{"rdot", "/", "h"}], "/", "e"}]}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"cf", ",", " ", "sf"}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"cpf", " ", "-", " ", "f"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cp", "/", "Degree"}], "]"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"cpdeg", ",", " ", "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"cpdeg", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"cpdeg", " ", "=", " ", 
        RowBox[{"cpdeg", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"ce", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r", "/", "a"}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"se", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "*", 
         RowBox[{"rdot", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"mu1", "*", "a"}], "]"}]}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"ea", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"ce", ",", "se"}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", "*", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ma", "+", "cp"}], ")"}], "/", "Degree"}], "]"}], ",", " ",
         "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lam", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"lam", " ", "=", " ", 
        RowBox[{"lam", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "a", ",", "e", ",", "cpdeg", ",", "lam"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.884599493746714*^9, 3.884599724772217*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7a749214-1746-4618-a6ff-697ddfaa8116"],

Cell[TextData[{
 "The function ",
 StyleBox["ae2xy", "Input"],
 " converts orbital elements to position and velocity.  Note that it assumes \
that the position and velocity are returned in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.884609242087802*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"454a8d3b-0bf3-479e-8a9f-22b4ef58bce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ae2xy", "[", 
   RowBox[{"mu_", ",", " ", "elements_List"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "a", ",", " ", 
      "e", ",", " ", "cpd", ",", " ", "lamd", ",", "cp", ",", "lam", ",", "n",
       ",", "ma", ",", "ea", ",", "rx", ",", "ry", ",", "r", ",", "ccp", ",", 
      "scp", ",", "eca", ",", "cea", ",", "sea", ",", "xdz", ",", "ydz", ",", 
      "xdi", ",", "ydi", ",", "ct", ",", "st", ",", "fe", ",", "x", ",", "y", 
      ",", "xd", ",", "yd", ",", "xi", ",", "yi"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "a", ",", " ", "e", ",", " ", "cpd", ",", " ", "lamd"}],
        "}"}], " ", "=", " ", "elements"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"fe", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"e", "^", "2"}]}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cpd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"ccp", " ", "=", " ", 
      RowBox[{"Cos", "[", "cp", "]"}]}], ";", 
     RowBox[{"scp", " ", "=", " ", 
      RowBox[{"Sin", "[", "cp", "]"}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"lamd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"mu1", "/", 
        RowBox[{"a", "^", "3"}]}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"lam", "-", "cp"}]}], ";", 
     RowBox[{"eca", " ", "=", " ", 
      RowBox[{"ea", " ", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ea", " ", "-", " ", 
           RowBox[{"e", " ", 
            RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}]}], ";", 
     RowBox[{"cea", " ", "=", " ", 
      RowBox[{"Cos", "[", "eca", "]"}]}], ";", 
     RowBox[{"sea", " ", "=", " ", 
      RowBox[{"Sin", "[", "eca", "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"cea", "-", "e"}], ")"}]}]}], ";", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{"a", "*", "fe", "*", "sea"}]}], ";", 
     RowBox[{"r", "  ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "cea"}]}], ")"}]}]}], ";", 
     RowBox[{"xdz", " ", "=", 
      RowBox[{
       RowBox[{"-", "n"}], "*", "a", "*", "a", "*", 
       RowBox[{"sea", "/", "r"}]}]}], ";", 
     RowBox[{"ydz", " ", "=", " ", 
      RowBox[{"n", "*", "a", "*", "a", "*", "fe", "*", 
       RowBox[{"cea", "/", "r"}]}]}], ";", 
     RowBox[{"xdi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "ccp"}], "-", 
       RowBox[{"ydz", "*", "scp"}]}]}], ";", 
     RowBox[{"ydi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "scp"}], "+", 
       RowBox[{"ydz", "*", "ccp"}]}]}], ";", 
     RowBox[{"xi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "ccp"}], "-", 
       RowBox[{"ry", "*", "scp"}]}]}], ";", 
     RowBox[{"yi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "scp"}], "+", 
       RowBox[{"ry", "*", "ccp"}]}]}], ";", 
     RowBox[{"x", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xi", "*", "ct"}], "+", 
       RowBox[{"yi", "*", "st"}]}]}], ";", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "xi"}], "*", "st"}], "+", 
       RowBox[{"yi", "*", "ct"}]}]}], ";", 
     RowBox[{"xd", " ", "=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xdi", "+", "yi"}], ")"}], "*", "ct"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"yd", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"xdi", "+", "yi"}], ")"}]}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "x", ",", "y", ",", "xd", ",", "yd"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.884599745435894*^9, 3.884599952174432*^9}, {
  3.884600220308159*^9, 3.8846002214146*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"24b4a3fc-1c40-4180-8325-aa48cae791c9"],

Cell[TextData[{
 "The function ",
 StyleBox["CRTBPPosVel", "Input"],
 " uses the ",
 StyleBox["CRTBP", "Input"],
 " function to solve the system of equations and produce a list of the time, \
position and velocity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.88460945213229*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9a6a5131-7620-4ff3-9655-567a4b693827"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBPPosVel", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", " ", "y0_", ",", " ", "xd0_", ",", " ", "yd0_"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"norb_", ",", "npo_"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dt", "=", 
      RowBox[{"2", "*", 
       RowBox[{"Pi", "/", "npo"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", "x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "==", "1"}], ",", " ", 
          RowBox[{"start", "=", 
           RowBox[{"{", 
            RowBox[{"x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}]}], ",", 
          " ", 
          RowBox[{"start", "=", "final"}]}], "]"}], ";", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"CRTBP", "[", 
          RowBox[{"mu", ",", " ", "start", ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], ";", 
        RowBox[{"pv", " ", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"N", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}], ",", " ", 
                RowBox[{"xd", "[", "t", "]"}], ",", " ", 
                RowBox[{"yd", "[", "t", "]"}]}], "}"}], " ", "/.", " ", 
              "sol"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", " ", "0", ",", " ", 
             RowBox[{"2", "*", "Pi"}], ",", " ", "dt"}], "}"}]}], "]"}]}], 
        ";", 
        RowBox[{"tpv", "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"N", "[", "tp", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"tp", ",", 
                 RowBox[{"i", "-", "1"}], ",", "i", ",", 
                 RowBox[{"1", "/", "npo"}]}], "}"}]}], "]"}], "}"}], ",", 
            RowBox[{"Transpose", "[", "pv", "]"}]}], "]"}], "]"}]}], ";", 
        RowBox[{"output", "=", 
         RowBox[{"Join", "[", 
          RowBox[{"output", ",", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"tpv", ",", "1"}], "]"}]}], "]"}]}], ";", 
        RowBox[{"final", "=", 
         RowBox[{"Last", "[", "pv", "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "norb"}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.88459998256313*^9, 3.884600101018793*^9}, {
   3.884605622093148*^9, 3.884605622449523*^9}, 3.885032927524745*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"d505b651-76c2-41bc-867a-dd0e0fd7ac8a"],

Cell["Set the colour to be used for the  plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.88504694541195*^9, 3.885046951921103*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ed9dfba6-c59a-40fa-957c-259cf15d9fb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.884607205132513*^9, 3.884607206710265*^9}, {
  3.885046927479679*^9, 3.885046927981505*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"c3cf32e8-fb70-49a8-8624-e51ebd63da22"],

Cell["Set the initial reference orbit.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.884609478322711*^9, 3.884609488822159*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"7998aaf6-022b-4941-b40f-2a4c2e076838"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Jacobi", "[", 
      RowBox[{"0.001", ",", 
       RowBox[{"{", 
        RowBox[{"0.55", ",", "0", ",", "0", ",", "ydot"}], "}"}]}], "]"}], 
     "-", "3.07"}], "==", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"ydot", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8849349940682993`*^9, 3.8849350903985777`*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"4c336dc7-1715-4767-bff0-483bfb56958e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"ydot", "\[Rule]", "0.9290256424097386`"}], "}"}]], "Output",
 CellChangeTimes->{3.884935092061715*^9, 3.884936716843547*^9, 
  3.884958917884006*^9, 3.885014755934483*^9, 3.885038115957757*^9, 
  3.885046842178609*^9, 3.885047012425585*^9, 3.891090970653543*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"0b40ab41-9301-4c48-bf2a-dc4ec62492fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xy2ae", "[", 
  RowBox[{"0.001", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.55", ",", "0", ",", "0", ",", "0.929026"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8849349227581387`*^9, 3.8849349641446457`*^9}, {
  3.884935101228853*^9, 3.884935105533313*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"26049063-1f50-4c18-b454-012dd6b145f6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.6912493268100347`", ",", "0.204339188960761`", ",", "0.`", ",",
    "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.884935107199417*^9, 3.884936716865252*^9, 
  3.8849589179388866`*^9, 3.8850147559994297`*^9, 3.885038116078999*^9, 
  3.885046842215075*^9, 3.88504701243856*^9, 3.891090970664123*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"c4ec471e-884a-4cbe-a1d3-9decd06e8520"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"initial", "=", 
  RowBox[{"ae2xy", "[", 
   RowBox[{"0.001", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "0", ",", " ", "0.691249", ",", " ", "0.204339", ",", " ", "0", ",", " ",
       "0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8845985677654247`*^9, 3.8845985828783283`*^9}, {
  3.8846001171281757`*^9, 3.884600143287702*^9}, {3.8846923887675734`*^9, 
  3.884692418767*^9}, {3.884934887043941*^9, 3.8849349003028507`*^9}, {
  3.884935191994259*^9, 3.884935202223465*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"14b3ea93-7315-4a69-ab54-8481f1a651a2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.549999870589`", ",", "0.`", ",", "0.`", ",", 
   "0.929026187383489`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.884600241368472*^9, 3.884611336250744*^9, {3.8846924235308743`*^9, 
   3.8846924431196957`*^9}, 3.88492687447575*^9, 3.884934027671545*^9, 
   3.8849349027636433`*^9, 3.884935205510832*^9, 3.884936716873268*^9, 
   3.884958917947445*^9, 3.885014756006049*^9, 3.885038116089779*^9, 
   3.885046842228271*^9, 3.885047012477871*^9, 3.891090970697929*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"db4d60f6-e2be-460a-9105-308d49356254"]
}, Open  ]],

Cell["\<\
Carry out the numerical integration for 600 Jupiter periods with 1000 points \
per orbit.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.884609528827335*^9}, {3.8846929395936604`*^9, 
   3.884692940103915*^9}, 3.884933818056218*^9, {3.88504319678268*^9, 
   3.885043197591806*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ce0f8a9c-90e8-4147-a7e9-c7c8734b7d83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBPPosVel", "[", 
   RowBox[{"0.001", ",", " ", 
    RowBox[{"Take", "[", 
     RowBox[{"initial", ",", 
      RowBox[{"-", "4"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"600", ",", "1000"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.884602418272439*^9, 3.884602490946604*^9}, {
   3.884692833635356*^9, 3.88469283462359*^9}, 3.884692950109296*^9, {
   3.884694188205783*^9, 3.884694195342669*^9}, 3.8849352162641277`*^9, {
   3.884971921778871*^9, 3.8849719227951517`*^9}, {3.884971965234537*^9, 
   3.884971969235817*^9}, {3.885043017113604*^9, 3.885043017828022*^9}, {
   3.8850430956561337`*^9, 3.885043096445792*^9}, {3.885043200836392*^9, 
   3.8850432014346857`*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"4b7e5027-a829-46ea-a699-58d2a31b2e98"],

Cell[TextData[{
 "Take the output data and store it in ",
 StyleBox["data", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c66e205f-f841-4f3b-b401-3beca64997b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", "output"}], ";"}]], "Input",
 CellChangeTimes->{{3.8846025272485447`*^9, 3.884602569500084*^9}, {
   3.884602604228772*^9, 3.884602608559495*^9}, 3.8849352265840397`*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"b5dfc9c5-9977-4724-8bb9-72a67b93fe5a"],

Cell["Partition the data into overlapping pairs of values.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.8850164355553703`*^9, 
   3.885016466305386*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a6a72254-afb1-480a-a609-d39b232faa6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdata", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{"data", ",", "2", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.884958972371325*^9, 3.884958996907157*^9}, {
  3.884971213593997*^9, 3.8849712452125683`*^9}, {3.885016425326809*^9, 
  3.885016426194372*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"cbf5b7f0-c6a8-41da-bee2-ce4758342f37"],

Cell[TextData[{
 "Select from the pairs those cases where the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " value changes from negative to positive.  This means that ",
 StyleBox["ydot",
  FontSlant->"Italic"],
 " > 0 and we can use this to calculate the values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["xdot",
  FontSlant->"Italic"],
 " when y = 0.  The values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["xdot",
  FontSlant->"Italic"],
 " will give us a point on the surface of section."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.885043218652596*^9, 
   3.885043244212302*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"00fcbe7e-c4ff-48d3-b2e3-1b83e804581d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spdata", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"pdata", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "<=", "0"}], "&&", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}], ">", "0"}]}], ")"}], 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8849712488918552`*^9, 3.884971345878228*^9}, {
  3.8849714433819113`*^9, 3.884971448598472*^9}, {3.885016480165959*^9, 
  3.885016487740059*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"28989704-952c-4a8b-80ec-9ba5c2c603e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"spdata", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.885028194904706*^9, 3.885028196492848*^9}, {
  3.885031561061322*^9, 3.8850315679798813`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"e9092624-329e-4987-8119-a06e81c8b31c"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "0", ",", "0.549999870589`", ",", "0.`", ",", "0.`", ",", 
        "0.929026187383489`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "0.001`", ",", "0.549982529105813`", ",", "0.005837118542657831`", ",", 
        RowBox[{"-", "0.005512975675943133`"}], ",", "0.9289693853762654`"}], 
       "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.284`", ",", "0.6957921733045128`", ",", 
        RowBox[{"-", "0.0027948737164303896`"}], ",", "0.25521113846412785`", 
        ",", "0.4722292918351757`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "1.285`", ",", "0.6973877168166185`", ",", "0.0001622644758490716`", 
        ",", "0.25267237520772673`", ",", "0.4690545534872152`"}], "}"}]}], 
     "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "447", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"598.635`", ",", "0.6972555065748527`", ",", 
        RowBox[{"-", "0.0005154748225891896`"}], ",", 
        RowBox[{"-", "0.26587378969243963`"}], ",", "0.46207670190913114`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "598.636`", ",", "0.6955767115386406`", ",", "0.002398344149761828`", 
        ",", 
        RowBox[{"-", "0.26850679807278`"}], ",", "0.4654225307073755`"}], 
       "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"599.897`", ",", "0.5399064329875228`", ",", 
        RowBox[{"-", "0.003895854164491007`"}], ",", 
        RowBox[{"-", "0.04531548634767968`"}], ",", "0.9578694899624863`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "599.898`", ",", "0.5396028803387836`", ",", "0.002124678018770039`", 
        ",", 
        RowBox[{"-", "0.05131819143156244`"}], ",", "0.9585063625116856`"}], 
       "}"}]}], "}"}]}], "}"}],
  Short[#, 10]& ]], "Output",
 CellChangeTimes->{3.8850281977404537`*^9, 3.885031569133872*^9, 
  3.885038166772978*^9, 3.885038851690989*^9, 3.885043037925086*^9, 
  3.885043149826383*^9, 3.8850468595804167`*^9, 3.885047029323851*^9, 
  3.891090987834993*^9},
 CellLabel->
  "Out[14]//Short=",ExpressionUUID->"574913fe-7490-4f76-8f0c-79d19319bc92"]
}, Open  ]],

Cell[TextData[{
 "Take the first value of each pair.  We are using a fixed interval of 0.001 \
orbital periods and so we just have to find the time at which ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0 occurs."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.8850415775728407`*^9, 
   3.885041646037519*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ca3f36a6-d42a-410c-a1a5-6f9b12963c3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fspdata", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "spdata", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.885041537631114*^9, 3.8850415645349493`*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"9eb3a93e-3375-4a3f-8d1a-c45742e23de0"],

Cell[TextData[{
 "Define a function ",
 StyleBox["Zoom", "Input"],
 " to zoom in on the crossing point.  It does this by repeating the \
integration over the same interval and then fitting the values of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " to calculate the value of the time when ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.885041306797385*^9, 
   3.8850413423777447`*^9}, {3.885042066171073*^9, 3.885042086106042*^9}, {
   3.885042945004177*^9, 3.8850429751686783`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b3609775-43ed-4809-b12e-6d9ff1e37b18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zoom", "[", "ival_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"zstart", ",", 
      RowBox[{"rt2", "=", 
       RowBox[{"N", "[", 
        RowBox[{"2", "*", 
         RowBox[{"\[Pi]", "/", "1000"}]}], "]"}]}], ",", "zsol", ",", "res", 
      ",", "tval", ",", "xvals", ",", "yvals", ",", "xdvals", ",", "ydval", 
      ",", "yfit", ",", "tfit", ",", "stfit", ",", "answer"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zstart", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"ival", ",", 
        RowBox[{"-", "4"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"zsol", "=", 
      RowBox[{"CRTBP", "[", 
       RowBox[{"0.001", ",", " ", "zstart", ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{"2", "*", 
           RowBox[{"\[Pi]", "/", "1000"}]}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", "=", "\[IndentingNewLine]", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{
                RowBox[{"t", "/", "2"}], "/", "\[Pi]"}], "]"}], ",", 
              RowBox[{"x", "[", "t", "]"}], ",", " ", 
              RowBox[{"y", "[", "t", "]"}], ",", " ", 
              RowBox[{"xd", "[", "t", "]"}], ",", " ", 
              RowBox[{"yd", "[", "t", "]"}]}], "}"}], "/.", " ", "zsol"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "rt2", ",", 
             RowBox[{"2", 
              RowBox[{"\[Pi]", "/", "10000"}]}]}], "}"}]}], "]"}], "]"}], ",",
         "5"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "tval", ",", "xvals", ",", "yvals", ",", "xdvals", ",", "ydval"}], 
       "}"}], "=", 
      RowBox[{"Transpose", "[", "res", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"yfit", "=", 
      RowBox[{"Fit", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"tval", ",", "yvals"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tfit", "=", 
      RowBox[{"x", "/.", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{"yfit", "==", "0"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"stfit", "=", 
      RowBox[{"tfit", "*", "2", "\[Pi]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"answer", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", "stfit", "]"}], ",", 
          RowBox[{"x", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"y", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"xd", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"yd", "[", "stfit", "]"}]}], "}"}], "/.", "zsol"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"answer", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"answer", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.885041356732667*^9, 3.885041357541669*^9}, 
   3.885041662688059*^9, {3.8850417350469513`*^9, 3.885041741872347*^9}, {
   3.885041814262137*^9, 3.88504181739717*^9}, {3.885041989319838*^9, 
   3.8850420430417833`*^9}, {3.885042115651099*^9, 3.885042124431017*^9}, {
   3.885042166890789*^9, 3.885042241491126*^9}, {3.885042271785565*^9, 
   3.885042436071013*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"7ebe3619-8c24-4dc1-825c-7c30deed09a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "fspdata", "]"}]], "Input",
 CellChangeTimes->{{3.885042472041195*^9, 3.885042475579356*^9}, {
  3.885042994248928*^9, 3.8850430008481617`*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"43d451e9-5b18-4fee-8dee-e18f061b526d"],

Cell[BoxData["451"], "Output",
 CellChangeTimes->{3.885042476925583*^9, 3.885043001820582*^9, 
  3.885043037997079*^9, 3.8850431498925343`*^9, 3.885046859627146*^9, 
  3.885047029391691*^9, 3.891090987924953*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"9f3f8a33-8be1-4e5c-a8ec-b29d5bc2ecca"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sspoints", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Zoom", "[", "#", "]"}], "&"}], ",", "fspdata"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.885042444565172*^9, 3.885042487204574*^9}, {
  3.885042708184396*^9, 3.8850427576244793`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"ba1b5dab-a065-476b-9303-5f2744d9ff6a"],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c3cda3e9-d160-4c42-87f3-5964d4020dd5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"x\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"x\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
OverscriptBox[
StyleBox[\"x\", \"TI\"], \".\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\dot x\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.851338850796014*^9, 3.851338856475478*^9}, {
  3.851339056483313*^9, 3.851339071079105*^9}, {3.8790751708185472`*^9, 
  3.879075193961151*^9}, {3.8790752823156977`*^9, 3.879075295960511*^9}, {
  3.8846966972447853`*^9, 3.884696730405851*^9}, {3.88493529231481*^9, 
  3.8849353055043716`*^9}, {3.8850433516886263`*^9, 3.885043376888672*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"2176cbc8-751f-447a-8aaf-0d34ef27e3ba"],

Cell["\<\
Now plot the points in the surface of section for this regular trajectory.  \
This is Fig.9.5.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}, {
  3.885043607290801*^9, 3.885043635581582*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2d732a05-09e5-4939-a202-e11b0caa4aca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"sspoints", ",", 
   RowBox[{"PlotStyle", "->", "color1"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.45", ",", "0.9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"ylabel", ",", 
        RowBox[{
         RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0.45", ",", 
      RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
   RowBox[{"PlotRangePadding", "->", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.885043417300242*^9, 3.885043497444316*^9}, 
   3.8850435453266973`*^9},
 CellLabel->"In[21]:=",ExpressionUUID->"60d4bcd2-7086-494a-8289-95440b1b21f0"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJwVl3c4le8fxymJUFFGVFYho+hLhfiQJNkiiiQjOyWVEJWZvbOSzQlJaCju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     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.45, -0.4},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[OverscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \\\".\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\dot \
x\\\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"x\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.45, 0.9}, {-0.4, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.885043164639765*^9, {3.885043482638938*^9, 3.8850434989739428`*^9}, 
   3.8850468617056227`*^9, 3.885047031414048*^9, 3.891090989922216*^9},
 CellLabel->"Out[21]=",ExpressionUUID->"554cb173-1228-44a9-bc0b-beb34cf337f7"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1055, 667},
WindowMargins->{{19, Automatic}, {Automatic, 21}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d38488ee-5b65-457a-a415-e5dca8af6771"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 489, 10, 53, "Text",ExpressionUUID->"9aff808c-ded9-4bf0-8637-19e7bf92455a"],
Cell[1050, 32, 380, 6, 67, "Section",ExpressionUUID->"98580719-04ac-49a4-b957-796e13d2fd0c"],
Cell[1433, 40, 425, 10, 72, "Text",ExpressionUUID->"2196beda-83cc-4949-84e5-6855091b3920"],
Cell[1861, 52, 4408, 115, 304, "Input",ExpressionUUID->"a0cc8023-92c0-48cc-8003-9af569b81a86"],
Cell[6272, 169, 356, 9, 53, "Text",ExpressionUUID->"e62b02b3-a858-4e86-bbbf-40af19ca2286"],
Cell[6631, 180, 1540, 45, 115, "Input",ExpressionUUID->"cc76bdeb-e5fc-4e00-a682-cd7f21c16a0c"],
Cell[8174, 227, 523, 12, 76, "Text",ExpressionUUID->"b21a35eb-c629-442c-bfb9-7016cce5ed6b"],
Cell[8700, 241, 5856, 160, 724, "Input",ExpressionUUID->"7a749214-1746-4618-a6ff-697ddfaa8116"],
Cell[14559, 403, 526, 12, 76, "Text",ExpressionUUID->"454a8d3b-0bf3-479e-8a9f-22b4ef58bce3"],
Cell[15088, 417, 4818, 128, 640, "Input",ExpressionUUID->"24b4a3fc-1c40-4180-8325-aa48cae791c9"],
Cell[19909, 547, 531, 14, 53, "Text",ExpressionUUID->"9a6a5131-7620-4ff3-9655-567a4b693827"],
Cell[20443, 563, 3222, 82, 283, "Input",ExpressionUUID->"d505b651-76c2-41bc-867a-dd0e0fd7ac8a"],
Cell[23668, 647, 424, 7, 53, "Text",ExpressionUUID->"ed9dfba6-c59a-40fa-957c-259cf15d9fb8"],
Cell[24095, 656, 363, 8, 33, "Input",ExpressionUUID->"c3cf32e8-fb70-49a8-8624-e51ebd63da22"],
Cell[24461, 666, 417, 7, 53, "Text",ExpressionUUID->"7998aaf6-022b-4941-b40f-2a4c2e076838"],
Cell[CellGroupData[{
Cell[24903, 677, 493, 13, 30, "Input",ExpressionUUID->"4c336dc7-1715-4767-bff0-483bfb56958e"],
Cell[25399, 692, 380, 6, 34, "Output",ExpressionUUID->"0b40ab41-9301-4c48-bf2a-dc4ec62492fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25816, 703, 374, 8, 30, "Input",ExpressionUUID->"26049063-1f50-4c18-b454-012dd6b145f6"],
Cell[26193, 713, 432, 8, 34, "Output",ExpressionUUID->"c4ec471e-884a-4cbe-a1d3-9decd06e8520"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26662, 726, 592, 12, 30, "Input",ExpressionUUID->"14b3ea93-7315-4a69-ab54-8481f1a651a2"],
Cell[27257, 740, 599, 11, 34, "Output",ExpressionUUID->"db4d60f6-e2be-460a-9105-308d49356254"]
}, Open  ]],
Cell[27871, 754, 608, 12, 53, "Text",ExpressionUUID->"ce0f8a9c-90e8-4147-a7e9-c7c8734b7d83"],
Cell[28482, 768, 815, 16, 30, "Input",ExpressionUUID->"4b7e5027-a829-46ea-a699-58d2a31b2e98"],
Cell[29300, 786, 552, 12, 53, "Text",ExpressionUUID->"c66e205f-f841-4f3b-b401-3beca64997b5"],
Cell[29855, 800, 296, 5, 30, "Input",ExpressionUUID->"b5dfc9c5-9977-4724-8bb9-72a67b93fe5a"],
Cell[30154, 807, 570, 9, 53, "Text",ExpressionUUID->"a6a72254-afb1-480a-a609-d39b232faa6f"],
Cell[30727, 818, 391, 8, 30, "Input",ExpressionUUID->"cbf5b7f0-c6a8-41da-bee2-ce4758342f37"],
Cell[31121, 828, 1194, 31, 76, "Text",ExpressionUUID->"00fcbe7e-c4ff-48d3-b2e3-1b83e804581d"],
Cell[32318, 861, 721, 20, 30, "Input",ExpressionUUID->"28989704-952c-4a8b-80ec-9ba5c2c603e2"],
Cell[CellGroupData[{
Cell[33064, 885, 283, 5, 30, "Input",ExpressionUUID->"e9092624-329e-4987-8119-a06e81c8b31c"],
Cell[33350, 892, 2320, 59, 112, "Output",ExpressionUUID->"574913fe-7490-4f76-8f0c-79d19319bc92"]
}, Open  ]],
Cell[35685, 954, 877, 17, 53, "Text",ExpressionUUID->"ca3f36a6-d42a-410c-a1a5-6f9b12963c3a"],
Cell[36565, 973, 317, 7, 30, "Input",ExpressionUUID->"9eb3a93e-3375-4a3f-8d1a-c45742e23de0"],
Cell[36885, 982, 1099, 23, 76, "Text",ExpressionUUID->"b3609775-43ed-4809-b12e-6d9ff1e37b18"],
Cell[37987, 1007, 3898, 98, 283, "Input",ExpressionUUID->"7ebe3619-8c24-4dc1-825c-7c30deed09a2"],
Cell[CellGroupData[{
Cell[41910, 1109, 261, 4, 30, "Input",ExpressionUUID->"43d451e9-5b18-4fee-8dee-e18f061b526d"],
Cell[42174, 1115, 291, 4, 34, "Output",ExpressionUUID->"9f3f8a33-8be1-4e5c-a8ec-b29d5bc2ecca"]
}, Open  ]],
Cell[42480, 1122, 391, 10, 30, "Input",ExpressionUUID->"ba1b5dab-a065-476b-9303-5f2744d9ff6a"],
Cell[42874, 1134, 656, 10, 53, "Text",ExpressionUUID->"c3cda3e9-d160-4c42-87f3-5964d4020dd5"],
Cell[43533, 1146, 993, 17, 54, "Input",ExpressionUUID->"2176cbc8-751f-447a-8aaf-0d34ef27e3ba"],
Cell[44529, 1165, 784, 14, 53, "Text",ExpressionUUID->"2d732a05-09e5-4939-a202-e11b0caa4aca"],
Cell[CellGroupData[{
Cell[45338, 1183, 1311, 34, 73, "Input",ExpressionUUID->"60d4bcd2-7086-494a-8289-95440b1b21f0"],
Cell[46652, 1219, 13517, 259, 271, "Output",ExpressionUUID->"554cb173-1228-44a9-bc0b-beb34cf337f7"]
}, Open  ]]
}
]
*)

